pub struct Proof {
pub report: Value,
pub inputs_hash: String,
pub report_hash: String,
pub engine_version: String,
}Expand description
The proof: the full backtest report plus the two canonical hashes and the exact engine version that produced it.
Fields
report: ValueThe full deterministic backtest report, embedded as JSON.
inputs_hash: Stringblake3 hex of canonicalize(inputs) where
inputs = {strategy, dataset_ref, candles, engine_version}.
report_hash: Stringblake3 hex of canonicalize(report).
engine_version: StringThe exact backtest engine version that produced report.